summaryrefslogtreecommitdiffstats
path: root/ui/views
diff options
context:
space:
mode:
authorpkasting <pkasting@chromium.org>2015-04-14 20:27:34 -0700
committerCommit bot <commit-bot@chromium.org>2015-04-15 03:29:04 +0000
commit67cb1e81f18652647625fac649d2359557465a49 (patch)
treebd88fa6553b68c81577642283b58bf7b487768be /ui/views
parentaa8dc11d2b5578b0d9bfce8bb15f2d91a3e085f3 (diff)
downloadchromium_src-67cb1e81f18652647625fac649d2359557465a49.zip
chromium_src-67cb1e81f18652647625fac649d2359557465a49.tar.gz
chromium_src-67cb1e81f18652647625fac649d2359557465a49.tar.bz2
Move some instrumentation from bug 431326 to bug 441028. Remove other
instrumentation that does not seem to be janky. BUG=431326,441028 TEST=none TBR=sky,mmenke Review URL: https://codereview.chromium.org/1091443002 Cr-Commit-Position: refs/heads/master@{#325180}
Diffstat (limited to 'ui/views')
-rw-r--r--ui/views/controls/label.cc13
-rw-r--r--ui/views/controls/label.h2
2 files changed, 4 insertions, 11 deletions
diff --git a/ui/views/controls/label.h b/ui/views/controls/label.h
index 8412272..b01d703 100644
--- a/ui/views/controls/label.h
+++ b/ui/views/controls/label.h
@@ -212,7 +212,7 @@ class VIEWS_EXPORT Label : public View {
bool collapse_when_hidden_;
int max_width_;
- // TODO(vadimt): Remove is_first_paint_text_ before crbug.com/431326 is
+ // TODO(ckocagil): Remove is_first_paint_text_ before crbug.com/441028 is
// closed.
bool is_first_paint_text_;
diff --git a/ui/views/controls/label.cc b/ui/views/controls/label.cc
index 3cd39079..57a50d7 100644
--- a/ui/views/controls/label.cc
+++ b/ui/views/controls/label.cc
@@ -214,10 +214,6 @@ int Label::GetBaseline() const {
}
gfx::Size Label::GetPreferredSize() const {
- // TODO(vadimt): Remove ScopedTracker below once crbug.com/431326 is fixed.
- tracked_objects::ScopedTracker tracking_profile(
- FROM_HERE_WITH_EXPLICIT_FUNCTION("431326 Label::GetPreferredSize"));
-
// Return a size of (0, 0) if the label is not visible and if the
// |collapse_when_hidden_| flag is set.
// TODO(munjal): This logic probably belongs to the View class. But for now,
@@ -361,17 +357,14 @@ void Label::OnBoundsChanged(const gfx::Rect& previous_bounds) {
void Label::OnPaint(gfx::Canvas* canvas) {
View::OnPaint(canvas);
if (is_first_paint_text_) {
// TODO(vadimt): Remove ScopedTracker below once crbug.com/431326 is fixed.
tracked_objects::ScopedTracker tracking_profile(
- FROM_HERE_WITH_EXPLICIT_FUNCTION("431326 Label::PaintText first"));
+ FROM_HERE_WITH_EXPLICIT_FUNCTION("441028 First PaintText()"));
is_first_paint_text_ = false;
PaintText(canvas);
} else {
- // TODO(vadimt): Remove ScopedTracker below once crbug.com/431326 is fixed.
- tracked_objects::ScopedTracker tracking_profile(
- FROM_HERE_WITH_EXPLICIT_FUNCTION("431326 Label::PaintText not first"));
-
PaintText(canvas);
}
if (HasFocus())
@@ -361,17 +357,14 @@ void Label::OnBoundsChanged(const gfx::Rect& previous_bounds) {
View::OnPaint(canvas);
if (is_first_paint_text_) {
- // TODO(vadimt): Remove ScopedTracker below once crbug.com/431326 is fixed.
+ // TODO(ckocagil): Remove ScopedTracker below once crbug.com/441028 is
+ // fixed.
tracked_objects::ScopedTracker tracking_profile(